# @step

This section contains the reference for the `@step` decorator, used to create new [`Step`][distilabel.steps.Step] subclasses without having to manually define the class.

For more information check the [Tutorial - Step](../../sections/how_to_guides/basic/step/index.md) page.

::: distilabel.steps.decorator
